
import { useState, useEffect, useCallback, memo } from "react";
import { Button } from "@/components/ui/button";
import { List, X } from "lucide-react";
import { Link, useLocation } from "react-router-dom";
import { 
  Drawer, 
  DrawerContent, 
  DrawerTrigger, 
  DrawerClose
} from "@/components/ui/drawer";

// Memoize the Header to prevent unnecessary re-renders
const Header = memo(() => {
  const [isScrolled, setIsScrolled] = useState(false);
  const location = useLocation();
  const isHomePage = location.pathname === '/';
  const [isOpen, setIsOpen] = useState(false);

  // Otimizar o gerenciamento do scroll com debounce para melhorar performance
  useEffect(() => {
    let lastScrollY = window.scrollY;
    let ticking = false;
    
    const handleScroll = () => {
      if (!ticking) {
        window.requestAnimationFrame(() => {
          setIsScrolled(window.scrollY > 10);
          ticking = false;
        });
        ticking = true;
      }
    };
    
    window.addEventListener("scroll", handleScroll, { passive: true });
    return () => window.removeEventListener("scroll", handleScroll);
  }, []);

  // Handle drawer open state
  const handleOpenChange = useCallback((open: boolean) => {
    setIsOpen(open);
    
    // Set body overflow based on the drawer state
    if (open) {
      document.body.style.overflow = 'hidden';
      console.log("Body overflow set to: hidden (drawer opened)");
    } else {
      document.body.style.overflow = 'auto';
      console.log("Body overflow set to: auto (drawer closed)");
    }
  }, []);

  // Garantir que o overflow seja restaurado ao desmontar
  useEffect(() => {
    return () => {
      document.body.style.overflow = 'auto';
    };
  }, []);

  // Componente de link para mobile que fecha o drawer após o clique
  const MobileLink = ({ to, children, className }: { to: string; children: React.ReactNode; className?: string }) => (
    <DrawerClose asChild>
      <Link 
        to={to} 
        className={className}
      >
        {children}
      </Link>
    </DrawerClose>
  );

  return (
    <header className={`fixed top-0 left-0 right-0 z-50 transition-all duration-300 ${isScrolled ? "glass-effect py-2" : "bg-transparent py-2 md:py-5"}`} role="banner">
      <div className="container mx-auto px-4 flex justify-between items-center">
        <div className="flex items-center">
          <Link to="/" className="flex items-center touch-target" aria-label="Ir para página inicial">
            <span className="text-lg md:text-2xl font-bold text-gradient">Codelo</span>
          </Link>
        </div>
        
        {/* Desktop Navigation */}
        <nav className="hidden md:flex items-center space-x-4 lg:space-x-8" aria-label="Navegação principal">
          {isHomePage ? 
            <Link 
              to="/" 
              className="text-foreground/90 hover:text-primary transition-all duration-300 font-medium text-sm py-2 touch-target focus-visible:outline-2 focus-visible:outline-primary focus-visible:outline-offset-2 focus-visible:rounded"
              aria-label="Ir para página inicial"
            >
              Início
            </Link> 
            : 
            <Link 
              to="/" 
              className="text-foreground/90 hover:text-primary transition-all duration-300 font-medium text-sm py-2 touch-target focus-visible:outline-2 focus-visible:outline-primary focus-visible:outline-offset-2 focus-visible:rounded"
              aria-label="Ir para página inicial"
            >
              Início
            </Link>
          }
          
          <Link 
            to="/sobre" 
            className="text-foreground/90 hover:text-primary transition-all duration-300 font-medium text-sm py-2 touch-target focus-visible:outline-2 focus-visible:outline-primary focus-visible:outline-offset-2 focus-visible:rounded"
            aria-label="Sobre nós"
          >
            Sobre nós
          </Link>
          
          <Link 
            to="/equipe" 
            className="text-foreground/90 hover:text-primary transition-all duration-300 font-medium text-sm py-2 mt-1 touch-target focus-visible:outline-2 focus-visible:outline-primary focus-visible:outline-offset-2 focus-visible:rounded"
            aria-label="Nossa equipe"
          >
            Nossa equipe
          </Link>
          
          <Link 
            to="/servicos" 
            className="text-foreground/90 hover:text-primary transition-all duration-300 font-medium text-sm py-2 touch-target focus-visible:outline-2 focus-visible:outline-primary focus-visible:outline-offset-2 focus-visible:rounded"
            aria-label="Ver serviços"
          >
            Conheça nossos serviços
          </Link>
          
          <Link to="/contato" aria-label="Entre em contato conosco">
            <Button className="bg-primary text-primary-foreground hover:opacity-90 rounded-full px-5 md:px-6 py-2 text-xs shadow-md whitespace-nowrap touch-target focus-visible:outline-2 focus-visible:outline-primary focus-visible:outline-offset-2">
              Entre em Contato
            </Button>
          </Link>
        </nav>
        
        {/* Mobile Menu - Drawer approach instead of hamburger */}
        <div className="md:hidden flex items-center">
          <Drawer open={isOpen} onOpenChange={handleOpenChange}>
            <DrawerTrigger asChild>
              <Button 
                variant="ghost" 
                size="icon" 
                className="text-foreground rounded-full w-14 h-14 p-1.5 touch-target mobile-menu-button" 
                aria-label="Abrir menu de navegação"
              >
                <List size={28} aria-hidden="true" />
                <span className="sr-only">Abrir menu</span>
              </Button>
            </DrawerTrigger>
            <DrawerContent className="p-0 focus-visible:outline-none">
              <div className="px-4 py-6 max-h-[90vh] overflow-y-auto">
                <div className="flex items-center justify-between mb-6">
                  <h2 className="text-xl font-bold">Menu de navegação</h2>
                  <DrawerClose asChild>
                    <Button variant="ghost" size="icon">
                      <X size={24} />
                      <span className="sr-only">Fechar menu</span>
                    </Button>
                  </DrawerClose>
                </div>
                
                <div className="flex flex-col space-y-4">
                  <MobileLink 
                    to="/" 
                    className="p-4 bg-muted hover:bg-muted/80 rounded-lg text-center text-xl font-medium touch-target focus-visible:outline-2 focus-visible:outline-primary focus-visible:outline-offset-2"
                  >
                    Início
                  </MobileLink>
                  
                  <MobileLink 
                    to="/sobre" 
                    className="p-4 bg-muted hover:bg-muted/80 rounded-lg text-center text-xl font-medium touch-target focus-visible:outline-2 focus-visible:outline-primary focus-visible:outline-offset-2"
                  >
                    Sobre nós
                  </MobileLink>
                  
                  <MobileLink 
                    to="/equipe" 
                    className="p-4 bg-muted hover:bg-muted/80 rounded-lg text-center text-xl font-medium touch-target focus-visible:outline-2 focus-visible:outline-primary focus-visible:outline-offset-2"
                  >
                    Nossa equipe
                  </MobileLink>
                  
                  <MobileLink 
                    to="/servicos" 
                    className="p-4 bg-muted hover:bg-muted/80 rounded-lg text-center text-xl font-medium touch-target focus-visible:outline-2 focus-visible:outline-primary focus-visible:outline-offset-2"
                  >
                    Conheça nossos serviços
                  </MobileLink>
                  
                  <div className="pt-4">
                    <MobileLink 
                      to="/contato" 
                      className="w-full"
                    >
                      <Button className="w-full bg-primary text-primary-foreground hover:opacity-90 py-6 text-xl font-medium rounded-lg">
                        Entre em Contato
                      </Button>
                    </MobileLink>
                  </div>
                </div>
              </div>
            </DrawerContent>
          </Drawer>
        </div>
      </div>
    </header>
  );
});

// Add display name for debugging
Header.displayName = "Header";

export default Header;
